Module data

Module data 

Data analysis routines

Functions

covariance_2
Compute the covariance matrix of a list of 2D points
covariance_3
Compute the covariance matrix of a list of 3D points
pca_2
2D principal component analysis
pca_3
3D principal component analysis