pub struct EntireBasis3<S>(/* private fields */);Implementations
Methods from Deref<Target = Matrix3<S>>
pub const ROW_COUNT: usize = 3
pub const COL_COUNT: usize = 3
Sourcepub fn is_packed(&self) -> bool
pub fn is_packed(&self) -> bool
Are all elements of this matrix tightly packed together in memory ?
This might not be the case for matrices in the repr_simd module
(it depends on the target architecture).
Sourcepub fn as_col_ptr(&self) -> *const T
pub fn as_col_ptr(&self) -> *const T
Gets a const pointer to this matrix’s elements.
Panics
Panics if the matrix’s elements are not tightly packed in memory,
which may be the case for matrices in the repr_simd module.
You may check this with the is_packed() method.
Sourcepub fn as_col_slice(&self) -> &[T]
pub fn as_col_slice(&self) -> &[T]
View this matrix as an immutable slice.
Panics
Panics if the matrix’s elements are not tightly packed in memory,
which may be the case for matrices in the repr_simd module.
You may check this with the is_packed() method.
pub const GL_SHOULD_TRANSPOSE: bool = false
Sourcepub fn gl_should_transpose(&self) -> bool
pub fn gl_should_transpose(&self) -> bool
Gets the transpose parameter to pass to OpenGL glUniformMatrix*() functions.
The return value is a plain bool which you may directly cast
to a GLboolean.
This takes &self to prevent surprises when changing the type
of matrix you plan to send.