Module distance

Module distance 

Nearest point and distance routines

Structs

Distance3

Functions

nearest_line2_point2
Nearest 2D point on a 2D line defined by a line segment
nearest_line3_line3
Returns the nearest points on given 3D lines
nearest_line3_point3
Nearest 3D point on a 3D line defined by a line segment
nearest_line3_segment3
Returns the nearest points in given 3D line and segment
nearest_segment2_point2
Returns the nearest point on a 2D segment
nearest_segment3_point3
Returns the nearest point on a 3D segment
nearest_segment3_segment3
Returns the nearest points on given 3D segments
nearest_triangle2_point2
Returns the nearest 2D point on 2D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$
nearest_triangle3_line3
Returns the nearest 3D point on 3D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$, and the nearest point in the 3D line defined by the segment endpoints together with parameter
nearest_triangle3_point3
Returns the nearest 3D point on 3D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$
nearest_triangle3_segment3
Returns the nearest 3D point on 3D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$, and the nearest point in the 3D segment
nearest_triangle3_triangle3
Returns the nearest 3D points two 3D triangles together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$