Module intersect

Module intersect 

Primitive intersection routines

Modules

integer
Intersection of Aabbs over Integers.

Functions

intersect_aabb2_aabb2
Boolean intersection computation of 2D axis-aligned bounding boxes.
intersect_aabb3_aabb3
Boolean intersection computation of 3D axis-aligned bounding boxes.
intersect_interval
Boolean intersection computation of 1D axis-aligned bounding boxes (intervals).
intersect_line2_aabb2
Boolean intersection computation of a 2D line with a 2D AABB (rectangle).
intersect_line2_sphere2
Boolean intersection computation of a 2D line with a 2D sphere (circle).
intersect_line3_aabb3
Boolean intersection computation of a 3D line with a 3D AABB.
intersect_line3_plane3
Boolean intersection computation of a 3D line with a 3D plane.
intersect_line3_sphere3
Boolean intersection computation of a 3D line with a 3D sphere.
intersect_line3_triangle3
Boolean intersection computation of a line with a triangle
intersect_ray2_aabb2
intersect_ray2_sphere2
intersect_ray3_aabb3
intersect_ray3_plane3
intersect_ray3_sphere3
intersect_ray3_triangle3
Boolean intersection computation of a ray with a triangle
intersect_segment2_aabb2
Boolean intersection computation of a 2D line segment with a 2D AABB (rectangle).
intersect_segment2_sphere2
Boolean intersection computation of a 2D line segment with a 2D sphere (circle).
intersect_segment3_aabb3
Boolean intersection computation of a 3D line segment with an AABB.
intersect_segment3_capsule3
Boolean intersection computation of a line segment with an axis-aligned capsule.
intersect_segment3_cylinder3
Boolean intersection computation of a 3D line segment with an axis-aligned cylinder.
intersect_segment3_hull3
Boolean intersection computation of a line segment with a convex hull.
intersect_segment3_sphere3
Boolean intersection computation of a 3D line segment with a sphere.
intersect_segment3_triangle3
Boolean intersection computation of a line segment with a triangle
line_triangle
Given an infinitely extended line defined by segment endpoints (a, b), check to see if line intersects a given triangle, returning parameterized position along the line $a + t (b - a)$.
overlaps_aabb2_aabb2
Overlap test of 2D axis-aligned bounding boxes.
overlaps_aabb3_aabb3
Overlap test of 3D axis-aligned bounding boxes.
overlaps_interval
Overlap test of 1D axis-aligned bounding boxes (intervals).
overlaps_sphere2_sphere2
Overlap test of 2D spheres.
overlaps_sphere3_sphere3
Overlap test of 3D spheres.
overlaps_triangle3_segment3
Overlap test of a line segment with a triangle
overlaps_triangle3_triangle3
Overlap test of two triangles