continuous_segment3_aabb3

Function continuous_segment3_aabb3 

pub fn continuous_segment3_aabb3<S>(
    segment: Segment3<S>,
    aabb: Aabb3<S>,
) -> Option<(Segment3Point<S>, Segment3Point<S>)>
where S: Real + Float + RelativeEq<Epsilon = S>,
Compute continuous intersection of a 3D line segment with an AABB.

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the AABB returns no intersection.