continuous_segment3_cylinder3

Function continuous_segment3_cylinder3 

pub fn continuous_segment3_cylinder3<S: Real>(
    segment: Segment3<S>,
    cylinder: Cylinder3<S>,
) -> Option<(Segment3Point<S>, Segment3Point<S>)>
Compute continuous intersection of a 3D line segment with an axis-aligned cylinder.

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the surface of the cylinder returns no intersection.