continuous_segment3_sphere3

Function continuous_segment3_sphere3 

pub fn continuous_segment3_sphere3<S>(
    segment: Segment3<S>,
    sphere: Sphere3<S>,
) -> Option<(Segment3Point<S>, Segment3Point<S>)>
where S: OrderedField + Sqrt,
Compute continuous intersection of a 3D line segment with a sphere.

The points are returned in the order given by the ordering of the points in the segment.

Note that a segment that is tangent to the surface of the sphere returns no intersection.