pub fn intersect_line3_triangle3<S>(
line: Line3<S>,
triangle: Triangle3<S>,
) -> Option<Line3Point<S>>Expand description
Boolean intersection computation of a line with a triangle
pub fn intersect_line3_triangle3<S>(
line: Line3<S>,
triangle: Triangle3<S>,
) -> Option<Line3Point<S>>Boolean intersection computation of a line with a triangle