intersect_segment3_capsule3

Function intersect_segment3_capsule3 

pub fn intersect_segment3_capsule3<S: Real>(
    segment: Segment3<S>,
    capsule: Capsule3<S>,
) -> Option<(Segment3Point<S>, Segment3Point<S>)>
Boolean intersection computation of a line segment with an axis-aligned capsule.

The points are returned in the order given by the ordering of the points in the segment.

Note that a line that is tangent to the surface of the capsule returns no intersection.