Tetrahedron

Struct Tetrahedron 

pub struct Tetrahedron<S> { /* private fields */ }
A 3-simplex or tetrahedron in 3D space

Creation methods will fail with a debug assertion if the points are coplanar.

Implementations

Source

impl<S: OrderedField> Tetrahedron<S>

pub fn new( a: Point3<S>, b: Point3<S>, c: Point3<S>, d: Point3<S>, ) -> Option<Self>
where S: AbsDiffEq<Epsilon = S>,

Returns None if the points are coplanar:

assert!(Tetrahedron::new (
  [-1.0, -1.0, -1.0].into(),
  [ 1.0,  1.0,  1.0].into(),
  [-1.0,  1.0,  0.0].into(),
  [ 1.0, -1.0,  0.0].into()
).is_none());
pub fn noisy(a: Point3<S>, b: Point3<S>, c: Point3<S>, d: Point3<S>) -> Self
where S: AbsDiffEq<Epsilon = S>,

Panics if the points are coplanar:

let s = Tetrahedron::noisy (
  [-1.0, -1.0, -1.0].into(),
  [ 1.0,  1.0,  1.0].into(),
  [-1.0,  1.0,  0.0].into(),
  [ 1.0, -1.0,  0.0].into());
pub fn unchecked(a: Point3<S>, b: Point3<S>, c: Point3<S>, d: Point3<S>) -> Self
where S: AbsDiffEq<Epsilon = S>,

Debug panic if the points are coplanar:

let s = Tetrahedron::unchecked (
  [-1.0, -1.0, -1.0].into(),
  [ 1.0,  1.0,  1.0].into(),
  [-1.0,  1.0,  0.0].into(),
  [ 1.0, -1.0,  0.0].into());
pub fn from_array([a, b, c, d]: [Point3<S>; 4]) -> Option<Self>
where S: AbsDiffEq<Epsilon = S>,

pub const fn point_a(self) -> Point3<S>

pub const fn point_b(self) -> Point3<S>

pub const fn point_c(self) -> Point3<S>

pub const fn point_d(self) -> Point3<S>

pub const fn points(self) -> [Point3<S>; 4]

pub const fn edge_ab(self) -> Segment3<S>

pub const fn edge_ac(self) -> Segment3<S>

pub const fn edge_ad(self) -> Segment3<S>

pub const fn edge_bc(self) -> Segment3<S>

pub const fn edge_bd(self) -> Segment3<S>

pub const fn edge_cd(self) -> Segment3<S>

pub const fn edges(self) -> [Segment3<S>; 6]

pub fn face_abc(self) -> Triangle<S>

Note that the points in the returned triangle will be ordered so that the triangle.normal() will face away from the tetrahedron.

pub fn face_abd(self) -> Triangle<S>

Note that the points in the returned triangle will be ordered so that the triangle.normal() will face away from the tetrahedron.

pub fn face_acd(self) -> Triangle<S>

Note that the points in the returned triangle will be ordered so that the triangle.normal() will face away from the tetrahedron.

pub fn face_bcd(self) -> Triangle<S>

Note that the points in the returned triangle will be ordered so that the triangle.normal() will face away from the tetrahedron.

pub fn faces(self) -> [Triangle<S>; 4]

pub fn normal_abc(self) -> NonZero3<S>

pub fn normal_abd(self) -> NonZero3<S>

pub fn normal_acd(self) -> NonZero3<S>

pub fn normal_bcd(self) -> NonZero3<S>

pub fn volume(self) -> Positive<S>

pub fn translate(&mut self, displacement: Vector3<S>)

pub fn contains(self, point: Point3<S>) -> bool

Checks if a point is contained in the tetrahedron:

let s = Tetrahedron::noisy (
  [ 0.0,  0.0,  1.0].into(),
  [ 0.0,  1.0, -1.0].into(),
  [-1.0, -1.0, -1.0].into(),
  [ 1.0, -1.0, -1.0].into()
);
assert!(s.contains (Point3::origin()));
assert!(!s.contains ([0.0, 0.0, 2.0].into()));