NonNegative

Struct NonNegative 

pub struct NonNegative<S>(/* private fields */);
Non-negative scalars (may be zero)

Implementations

Source

impl<S> NonNegative<S>
where S: PartialOrd + Zero,

pub fn new(value: S) -> Option<Self>

Returns ‘None’ when called with a negative value.

Example
assert!(NonNegative::new (1.0).is_some());
assert!(NonNegative::new (0.0).is_some());
assert!(NonNegative::new (-1.0).is_none());
pub fn noisy(value: S) -> Self

Panics if negative.

Panics
let x = NonNegative::noisy (-1.0);  // panic!
pub fn unchecked(value: S) -> Self

Create a new non-negative number without checking the value.

This method is completely unchecked for release builds. Debug builds will panic if the value is negative:

let negative = NonNegative::unchecked (-1.0);   // panic!
pub fn map_noisy<F>(self, fun: F) -> Self
where F: FnMut(S) -> S,

Map an operation on the underlying scalar, panicking if the result is negative.

Example
assert_eq!(*NonNegative::abs (1.0).map_noisy (|x| 2.0 * x), 2.0);
Panics

Panics of the result is negative:

let v = NonNegative::abs (1.0).map_noisy (|x| -1.0 * x);  // panic!
Source

impl<S> NonNegative<S>
where S: Signed,

pub fn abs(value: S) -> Self

Converts negative input to absolute value.

Example
assert_eq!(*NonNegative::abs (1.0), 1.0);
assert_eq!(*NonNegative::abs (-1.0), 1.0);
pub fn map_abs<F>(self, fun: F) -> Self
where F: FnMut(S) -> S,

Map an operation on the underlying scalar, converting negative result to an absolute value.

Example
assert_eq!(*NonNegative::abs (1.0).map_abs (|x| -2.0 * x), 2.0);
Source

impl NonNegative<f32>

pub const fn new_f32(value: f32) -> Option<Self>

Const constructor for f32

pub const fn noisy_f32(value: f32) -> Self

Const constructor for f32 with assertions

pub const fn unchecked_f32(value: f32) -> Self

Const constructor for f32 with debug assertions

Source

impl NonNegative<f64>

pub const fn new_f64(value: f64) -> Option<Self>

Const constructor for f64

pub const fn noisy_f64(value: f64) -> Self

Const constructor for f64 with assertions

pub const fn unchecked_f64(value: f64) -> Self

Const constructor for f64 with debug assertions

Source

impl<S> NonNegative<S>

pub fn numcast<T>(self) -> Option<NonNegative<T>>
where S: NumCast, T: NumCast,