pub struct NonZero<S>(/* private fields */);Expand description
Non-zero scalars
Implementations
Sourceimpl<S> NonZero<S>
impl<S> NonZero<S>
Sourcepub fn new(value: S) -> Option<Self>
pub fn new(value: S) -> Option<Self>
Returns ‘None’ when called with zero.
Example
assert!(NonZero::new (2.0).is_some());
assert!(NonZero::new (0.0).is_none());
assert!(NonZero::new (-2.0).is_some());Trait Implementations
impl<S: Copy> Copy for NonZero<S>
impl<S: PartialEq> Eq for NonZero<S>
Sourceimpl<S: MultiplicativeMonoid> Mul for NonZero<S>
impl<S: MultiplicativeMonoid> Mul for NonZero<S>
Sourceimpl<S: MultiplicativeMonoid> One for NonZero<S>
impl<S: MultiplicativeMonoid> One for NonZero<S>
Sourceimpl<S: PartialEq> PartialEq for NonZero<S>
impl<S: PartialEq> PartialEq for NonZero<S>
Sourceimpl<S: PartialOrd> PartialOrd for NonZero<S>
impl<S: PartialOrd> PartialOrd for NonZero<S>
impl<S> StructuralPartialEq for NonZero<S>
Sourceimpl<S> ToPrimitive for NonZero<S>where
S: ToPrimitive,
impl<S> ToPrimitive for NonZero<S>where
S: ToPrimitive,
Sourcefn to_isize(&self) -> Option<isize>
fn to_isize(&self) -> Option<isize>
Converts the value of
self to an isize. If the value cannot be
represented by an isize, then None is returned.Sourcefn to_i8(&self) -> Option<i8>
fn to_i8(&self) -> Option<i8>
Converts the value of
self to an i8. If the value cannot be
represented by an i8, then None is returned.Sourcefn to_i16(&self) -> Option<i16>
fn to_i16(&self) -> Option<i16>
Converts the value of
self to an i16. If the value cannot be
represented by an i16, then None is returned.Sourcefn to_i32(&self) -> Option<i32>
fn to_i32(&self) -> Option<i32>
Converts the value of
self to an i32. If the value cannot be
represented by an i32, then None is returned.Sourcefn to_i64(&self) -> Option<i64>
fn to_i64(&self) -> Option<i64>
Converts the value of
self to an i64. If the value cannot be
represented by an i64, then None is returned.Sourcefn to_usize(&self) -> Option<usize>
fn to_usize(&self) -> Option<usize>
Converts the value of
self to a usize. If the value cannot be
represented by a usize, then None is returned.Sourcefn to_u8(&self) -> Option<u8>
fn to_u8(&self) -> Option<u8>
Converts the value of
self to a u8. If the value cannot be
represented by a u8, then None is returned.Sourcefn to_u16(&self) -> Option<u16>
fn to_u16(&self) -> Option<u16>
Converts the value of
self to a u16. If the value cannot be
represented by a u16, then None is returned.Sourcefn to_u32(&self) -> Option<u32>
fn to_u32(&self) -> Option<u32>
Converts the value of
self to a u32. If the value cannot be
represented by a u32, then None is returned.Sourcefn to_u64(&self) -> Option<u64>
fn to_u64(&self) -> Option<u64>
Converts the value of
self to a u64. If the value cannot be
represented by a u64, then None is returned.Sourcefn to_f32(&self) -> Option<f32>
fn to_f32(&self) -> Option<f32>
Converts the value of
self to an f32. Overflows may map to positive
or negative inifinity, otherwise None is returned if the value cannot
be represented by an f32.Sourcefn to_f64(&self) -> Option<f64>
fn to_f64(&self) -> Option<f64>
Converts the value of
self to an f64. Overflows may map to positive
or negative inifinity, otherwise None is returned if the value cannot
be represented by an f64. Read moreAuto Trait Implementations
impl<S> Freeze for NonZero<S>where
S: Freeze,
impl<S> RefUnwindSafe for NonZero<S>where
S: RefUnwindSafe,
impl<S> Send for NonZero<S>where
S: Send,
impl<S> Sync for NonZero<S>where
S: Sync,
impl<S> Unpin for NonZero<S>where
S: Unpin,
impl<S> UnsafeUnpin for NonZero<S>where
S: UnsafeUnpin,
impl<S> UnwindSafe for NonZero<S>where
S: UnwindSafe,