pub struct NormalSigned<S>(/* private fields */);Expand description
Scalars in the closed interval [-1, 1]
Implementations
Sourceimpl<S> NormalSigned<S>
impl<S> NormalSigned<S>
pub fn zero() -> Selfwhere
S: Zero,
pub fn is_zero(&self) -> boolwhere
S: Zero,
Sourcepub fn new(value: S) -> Option<Self>where
S: OrderedRing,
pub fn new(value: S) -> Option<Self>where
S: OrderedRing,
Returns ‘None’ when called with a value outside of the closed interval [-1,1].
Example
assert!(NormalSigned::new (2.0).is_none());
assert!(NormalSigned::new (1.0).is_some());
assert!(NormalSigned::new (0.5).is_some());
assert!(NormalSigned::new (0.0).is_some());
assert!(NormalSigned::new (-1.0).is_some());
assert!(NormalSigned::new (-2.0).is_none());Sourcepub fn clamp(value: S) -> Self
pub fn clamp(value: S) -> Self
Clamps to the closed interval [-1,1].
Example
assert_eq!(*NormalSigned::clamp (2.0), 1.0);
assert_eq!(*NormalSigned::clamp (-2.0), -1.0);Sourcepub fn noisy(value: S) -> Selfwhere
S: OrderedRing,
pub fn noisy(value: S) -> Selfwhere
S: OrderedRing,
Sourcepub fn map_clamp<F>(self, fun: F) -> Self
pub fn map_clamp<F>(self, fun: F) -> Self
Map an operation on the underlying scalar, clamping results to the closed interval [-1,1].
Example
assert_eq!(*NormalSigned::<f64>::one().map_clamp (|x| 2.0 * x), 1.0);
assert_eq!(*NormalSigned::<f64>::one().map_clamp (|x| -2.0 * x), -1.0);Sourcepub fn map_noisy<F>(self, fun: F) -> Selfwhere
S: OrderedRing,
F: FnMut(S) -> S,
pub fn map_noisy<F>(self, fun: F) -> Selfwhere
S: OrderedRing,
F: FnMut(S) -> S,
Map an operation on the underlying scalar, panicking if the result is outside the interval [-1, 1].
Example
assert_eq!(*NormalSigned::<f64>::one().map_noisy (|x| 0.5 * x), 0.5);Panics
Panics of the result is outside [-1, 1]:
ⓘ
let v = NormalSigned::<f64>::one().map_noisy (|x| -2.0 * x); // panic!ⓘ
let v = NormalSigned::<f64>::one().map_noisy (|x| 2.0 * x); // panic!Sourceimpl NormalSigned<f32>
impl NormalSigned<f32>
Sourceimpl NormalSigned<f64>
impl NormalSigned<f64>
Sourceimpl<S> NormalSigned<S>
impl<S> NormalSigned<S>