Normalized

Struct Normalized 

pub struct Normalized<S>(/* private fields */);
Scalars in the closed unit interval [0, 1]

Implementations

Source

impl<S> Normalized<S>
where S: One + Zero,

pub fn zero() -> Self

pub fn is_zero(&self) -> bool

pub fn new(value: S) -> Option<Self>
where S: PartialOrd,

Returns ‘None’ when called with a value outside of the closed unit interval [0,1].

Example
assert!(Normalized::new (2.0).is_none());
assert!(Normalized::new (1.0).is_some());
assert!(Normalized::new (0.5).is_some());
assert!(Normalized::new (0.0).is_some());
assert!(Normalized::new (-1.0).is_none());
pub fn clamp(value: S) -> Self
where S: MinMax,

Clamps to the closed unit interval [0,1].

Example
assert_eq!(*Normalized::clamp (2.0), 1.0);
assert_eq!(*Normalized::clamp (-1.0), 0.0);
pub fn noisy(value: S) -> Self
where S: PartialOrd,

Panics if outside the closed unit interval [0,1].

Panics
let x = Normalized::noisy (-1.0);  // panic!
let x = Normalized::noisy (2.0);  // panic!
pub fn unchecked(value: S) -> Self
where S: PartialOrd,

Create a new normalized number without checking the value.

This method is completely unchecked for release builds. Debug builds will panic if the value is negative:

let normalized = Normalized::unchecked (1.5);   // panic!
pub fn map_clamp<F>(self, fun: F) -> Self
where S: MinMax, F: FnMut(S) -> S,

Map an operation on the underlying scalar, clamping results to the closed unit interval [0,1].

Example
assert_eq!(*Normalized::<f64>::one().map_clamp (|x|  2.0 * x), 1.0);
assert_eq!(*Normalized::<f64>::one().map_clamp (|x| -2.0 * x), 0.0);
pub fn map_noisy<F>(self, fun: F) -> Self
where S: PartialOrd, F: FnMut(S) -> S,

Map an operation on the underlying scalar, panicking if the result is outside the unit interval [0,1].

Example
assert_eq!(*Normalized::<f64>::one().map_noisy (|x| 0.5 * x), 0.5);
Panics

Panics of the result is outside [0,1]:

let v = Normalized::<f64>::one().map_noisy (|x| -1.0 * x);  // panic!
let v = Normalized::<f64>::one().map_noisy (|x|  2.0 * x);  // panic!
Source

impl Normalized<f32>

pub const fn new_f32(value: f32) -> Option<Self>

Const constructor for f32

pub const fn noisy_f32(value: f32) -> Self

Const constructor for f32 with assertions

pub const fn unchecked_f32(value: f32) -> Self

Const constructor for f32 with debug assertions

Source

impl Normalized<f64>

pub const fn new_f64(value: f64) -> Option<Self>

Const constructor for f64

pub const fn noisy_f64(value: f64) -> Self

Const constructor for f64 with assertions

pub const fn unchecked_f64(value: f64) -> Self

Const constructor for f64 with debug assertions

Source

impl<S> Normalized<S>

pub fn numcast<T>(self) -> Option<Normalized<T>>
where S: NumCast, T: NumCast,