Nearest point and distance routines
Structs
Functions
- nearest_
line2_ point2 - Nearest 2D point on a 2D line defined by a line segment
- nearest_
line3_ line3 - Returns the nearest points on given 3D lines
- nearest_
line3_ point3 - Nearest 3D point on a 3D line defined by a line segment
- nearest_
line3_ segment3 - Returns the nearest points in given 3D line and segment
- nearest_
segment2_ point2 - Returns the nearest point on a 2D segment
- nearest_
segment3_ point3 - Returns the nearest point on a 3D segment
- nearest_
segment3_ segment3 - Returns the nearest points on given 3D segments
- nearest_
triangle2_ point2 - Returns the nearest 2D point on 2D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$
- nearest_
triangle3_ line3 - Returns the nearest 3D point on 3D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$, and the nearest point in the 3D line defined by the segment endpoints together with parameter
- nearest_
triangle3_ point3 - Returns the nearest 3D point on 3D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$
- nearest_
triangle3_ segment3 - Returns the nearest 3D point on 3D triangle together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$, and the nearest point in the 3D segment
- nearest_
triangle3_ triangle3 - Returns the nearest 3D points two 3D triangles together with barycentric coordinates in relation to the triangle edges $ab$ and $ac$