Primitive intersection routines
Modules
- integer
- Intersection of Aabbs over Integers.
Functions
- intersect_
aabb2_ aabb2 - Boolean intersection computation of 2D axis-aligned bounding boxes.
- intersect_
aabb3_ aabb3 - Boolean intersection computation of 3D axis-aligned bounding boxes.
- intersect_
interval - Boolean intersection computation of 1D axis-aligned bounding boxes (intervals).
- intersect_
line2_ aabb2 - Boolean intersection computation of a 2D line with a 2D AABB (rectangle).
- intersect_
line2_ sphere2 - Boolean intersection computation of a 2D line with a 2D sphere (circle).
- intersect_
line3_ aabb3 - Boolean intersection computation of a 3D line with a 3D AABB.
- intersect_
line3_ plane3 - Boolean intersection computation of a 3D line with a 3D plane.
- intersect_
line3_ sphere3 - Boolean intersection computation of a 3D line with a 3D sphere.
- intersect_
line3_ triangle3 - Boolean intersection computation of a line with a triangle
- intersect_
ray2_ aabb2 - intersect_
ray2_ sphere2 - intersect_
ray3_ aabb3 - intersect_
ray3_ plane3 - intersect_
ray3_ sphere3 - intersect_
ray3_ triangle3 - Boolean intersection computation of a ray with a triangle
- intersect_
segment2_ aabb2 - Boolean intersection computation of a 2D line segment with a 2D AABB (rectangle).
- intersect_
segment2_ sphere2 - Boolean intersection computation of a 2D line segment with a 2D sphere (circle).
- intersect_
segment3_ aabb3 - Boolean intersection computation of a 3D line segment with an AABB.
- intersect_
segment3_ capsule3 - Boolean intersection computation of a line segment with an axis-aligned capsule.
- intersect_
segment3_ cylinder3 - Boolean intersection computation of a 3D line segment with an axis-aligned cylinder.
- intersect_
segment3_ hull3 - Boolean intersection computation of a line segment with a convex hull.
- intersect_
segment3_ sphere3 - Boolean intersection computation of a 3D line segment with a sphere.
- intersect_
segment3_ triangle3 - Boolean intersection computation of a line segment with a triangle
- line_
triangle - Given an infinitely extended line defined by segment endpoints (a, b), check to see if line intersects a given triangle, returning parameterized position along the line $a + t (b - a)$.
- overlaps_
aabb2_ aabb2 - Overlap test of 2D axis-aligned bounding boxes.
- overlaps_
aabb3_ aabb3 - Overlap test of 3D axis-aligned bounding boxes.
- overlaps_
interval - Overlap test of 1D axis-aligned bounding boxes (intervals).
- overlaps_
sphere2_ sphere2 - Overlap test of 2D spheres.
- overlaps_
sphere3_ sphere3 - Overlap test of 3D spheres.
- overlaps_
triangle3_ segment3 - Overlap test of a line segment with a triangle
- overlaps_
triangle3_ triangle3 - Overlap test of two triangles