pub fn plane_side_3d<S>(
a: Point3<S>,
b: Point3<S>,
c: Point3<S>,
d: Point3<S>,
) -> Swhere
S: OrderedField + AbsDiffEq<Epsilon = S>,Expand description
Return a signum indicating which side of the triangle ABC that point D lies on, where +1 indicates that D lies on the side that the normal $(B - A) \times (C - A)$ points to, -1 if D lies on the opposite side, and 0 if D lies on the plane ABC, within tolerance