pub struct Normalized<S>(/* private fields */);Expand description
Scalars in the closed unit interval [0, 1]
Implementations
Sourceimpl<S> Normalized<S>
impl<S> Normalized<S>
pub fn zero() -> Self
pub fn is_zero(&self) -> bool
Sourcepub fn new(value: S) -> Option<Self>where
S: PartialOrd,
pub fn new(value: S) -> Option<Self>where
S: PartialOrd,
Returns ‘None’ when called with a value outside of the closed unit interval [0,1].
Example
assert!(Normalized::new (2.0).is_none());
assert!(Normalized::new (1.0).is_some());
assert!(Normalized::new (0.5).is_some());
assert!(Normalized::new (0.0).is_some());
assert!(Normalized::new (-1.0).is_none());Sourcepub fn clamp(value: S) -> Selfwhere
S: MinMax,
pub fn clamp(value: S) -> Selfwhere
S: MinMax,
Clamps to the closed unit interval [0,1].
Example
assert_eq!(*Normalized::clamp (2.0), 1.0);
assert_eq!(*Normalized::clamp (-1.0), 0.0);Sourcepub fn noisy(value: S) -> Selfwhere
S: PartialOrd,
pub fn noisy(value: S) -> Selfwhere
S: PartialOrd,
Sourcepub fn unchecked(value: S) -> Selfwhere
S: PartialOrd,
pub fn unchecked(value: S) -> Selfwhere
S: PartialOrd,
Create a new normalized number without checking the value.
This method is completely unchecked for release builds. Debug builds will panic if the value is negative:
ⓘ
let normalized = Normalized::unchecked (1.5); // panic!Sourcepub fn map_clamp<F>(self, fun: F) -> Self
pub fn map_clamp<F>(self, fun: F) -> Self
Map an operation on the underlying scalar, clamping results to the closed unit interval [0,1].
Example
assert_eq!(*Normalized::<f64>::one().map_clamp (|x| 2.0 * x), 1.0);
assert_eq!(*Normalized::<f64>::one().map_clamp (|x| -2.0 * x), 0.0);Sourcepub fn map_noisy<F>(self, fun: F) -> Selfwhere
S: PartialOrd,
F: FnMut(S) -> S,
pub fn map_noisy<F>(self, fun: F) -> Selfwhere
S: PartialOrd,
F: FnMut(S) -> S,
Map an operation on the underlying scalar, panicking if the result is outside the unit interval [0,1].
Example
assert_eq!(*Normalized::<f64>::one().map_noisy (|x| 0.5 * x), 0.5);Panics
Panics of the result is outside [0,1]:
ⓘ
let v = Normalized::<f64>::one().map_noisy (|x| -1.0 * x); // panic!ⓘ
let v = Normalized::<f64>::one().map_noisy (|x| 2.0 * x); // panic!Sourceimpl Normalized<f32>
impl Normalized<f32>
Sourceimpl Normalized<f64>
impl Normalized<f64>
Sourceimpl<S> Normalized<S>
impl<S> Normalized<S>